<?php

use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/
Route::group(['prefix' => LaravelLocalization::setLocale()], function() {
    Route::get('/', [App\Http\Controllers\HomeController::class, 'index'])->name('home');

    Auth::routes();

    Route::get('/dashboard', [App\Http\Controllers\HomeController::class, 'index'])->name('home');

    Route::group(['middleware' => 'auth', 'prefix' => 'payment'], function () {
        Route::get('/', [App\Http\Controllers\PaymentController::class, 'index'])->name('payment.index');
        Route::post('/pay', [App\Http\Controllers\PaymentController::class, 'store'])->name('payment.store');
    });
    Route::group(['middleware' => 'auth', 'prefix' => 'questions'], function () {
        Route::get('/', [App\Http\Controllers\QuestionController::class, 'index'])->name('questions.index');
        Route::get('/create', [App\Http\Controllers\QuestionController::class, 'create'])->name('question.create');
        Route::post('/create', [App\Http\Controllers\QuestionController::class, 'store'])->name('question.store');
        Route::get('/edit/{id}', [App\Http\Controllers\QuestionController::class, 'edit'])->name('question.edit');
        Route::post('/edit', [App\Http\Controllers\QuestionController::class, 'update'])->name('question.update');
    });
    Route::group(['middleware' => 'auth', 'prefix' => 'categories'], function () {
        Route::get('/', [App\Http\Controllers\CategoryController::class, 'index'])->name('categories.index');
        Route::get('/create', [App\Http\Controllers\CategoryController::class, 'create'])->name('category.create');
        Route::post('/create', [App\Http\Controllers\CategoryController::class, 'store'])->name('category.store');
    });


    Route::group(['middleware' => 'auth', 'prefix' => 'careful-test'], function () {
        Route::get('/', [App\Http\Controllers\DesignExamController::class, 'payment'])->name('design_exam.payment');
        Route::post('/create', [App\Http\Controllers\DesignExamController::class, 'create'])->name('careful_exam.create');
        Route::post('/store', [App\Http\Controllers\DesignExamController::class, 'store'])->name('design_exam.store');


        Route::get('/my-tests', [App\Http\Controllers\DesignExamController::class, 'frontend'])->name('careful_testings.my_tests');
        Route::get('/index', [App\Http\Controllers\DesignExamController::class, 'index'])->name('careful_testings.index');
        Route::get('/index/{id}', [App\Http\Controllers\DesignExamController::class, 'updateStatus'])->name('update.status');

        Route::get('/upload/{id}', [App\Http\Controllers\DesignExamController::class, 'upload'])->name('result.create');
        Route::post('/upload', [App\Http\Controllers\DesignExamController::class, 'uploadResults'])->name('results.upload');

    });

    Route::group(['middleware' => 'auth', 'prefix' => 'profile'], function () {
        Route::post('/profile/update/{id}', [App\Http\Controllers\ProfileController::class, 'update'])->name('profile.update');
    });

    Route::group(['middleware' => 'auth', 'prefix' => 'exam'], function () {
        Route::get('/exams', [App\Http\Controllers\ExamController::class, 'index'])->name('exam.index');
        Route::get('/start', [App\Http\Controllers\QuizController::class, 'start'])->name('exam.start');
        Route::get('/details/{id}', [App\Http\Controllers\QuizController::class, 'show'])->name('exam.show');
    });

    Route::group(['middleware' => 'auth', 'prefix' => 'dashboard'], function () {
        Route::get('/exams', [App\Http\Controllers\ExamController::class, 'dashboard'])->name('dashboard.exams.index');
    });
    Route::group(['middleware' => 'auth', 'prefix' => 'codes'], function () {
        Route::get('/', [App\Http\Controllers\CodeController::class, 'index'])->name('codes.index');
        Route::get('/generate', [App\Http\Controllers\CodeController::class, 'create'])->name('codes.create');
        Route::post('/generate', [App\Http\Controllers\CodeController::class, 'store'])->name('codes.store');

        Route::get('/my_codes', [App\Http\Controllers\CodeController::class, 'my_codes'])->name('my_codes.index');

        Route::get('/export/{team_id}',[App\Http\Controllers\CodeController::class, 'export'])->name('codes.export');
    });


    Route::group(['middleware' => 'auth', 'prefix' => 'team'], function () {
        Route::get('/index', [App\Http\Controllers\TeamWorkController::class, 'index'])->name('team.index');
        Route::get('/create/{category_id}', [App\Http\Controllers\TeamWorkController::class, 'create'])->name('team.create');
        Route::get('/show/{category_id}', [App\Http\Controllers\TeamWorkController::class, 'show'])->name('team.show');
        Route::get('/codes/{team_id}', [App\Http\Controllers\TeamWorkController::class, 'codes'])->name('team.codes');
        Route::post('/create', [App\Http\Controllers\TeamWorkController::class, 'store'])->name('team.store');

        Route::get('/exam-details/{exam_code}', [App\Http\Controllers\TeamWorkController::class, 'exam_details'])->name('team.exam.details');
    });

    Route::group(['middleware' => 'auth', 'prefix' => 'team-category'], function () {
        Route::get('/create', [App\Http\Controllers\TeamCategoryController::class, 'create'])->name('team.category.create');
        Route::post('/create', [App\Http\Controllers\TeamCategoryController::class, 'store'])->name('team.category.store');
    });
    Route::group(['prefix' => 'team-exam'], function () {
        Route::get('/', [App\Http\Controllers\TeamWorkController::class, 'exam'])->name('team.exam');
    });

    Route::post('exam/create', [App\Http\Controllers\QuizController::class, 'new'])->name('exam.new');
    Route::post('exam/new', [App\Http\Controllers\QuizController::class, 'store'])->name('exam.store');

});
